@@ -14,7 +14,7 @@ WAIT_TIME = re.compile(r"You have (?:(\d+)m )?(\d+)s left to wait.")
 def get_cookie():
     token_file = DATA_DIR / "token.txt"
     if token_file.exists():
-        return {"session": token_file.read_text()}
+        return {"session": token_file.read_text().strip('\n')}
     token = input("Could not find configuration file. Please enter your token\n>>> ")
     token_file.write_text(token)
     return {"session": token}
